{% extends "layout/default.html" %}
{% block body %}

	<h1>Options</h1>

	<a href="{{ url_for('maj') }}" class="btn {{ buttonColor }}">Mettre à jour Onyx</a>

{% endblock %}
{% block script %}


{% endblock %}
