{% extends "layout/default.html" %}
{% block body %}

	<h1>Mes applications</h1>

	<div class="row">
		
		<div class="col s2 offset-s2">
		<a href="{{ url_for('tv') }}" class="btn-floating btn-large {{ buttonColor }}">
		    <i class="large material-icons">tv</i>
		</a>
		</div>

		<div class="col s2">
		<a href="{{ url_for('wiki') }}" class="btn-floating btn-large {{ buttonColor }}">
		    <i class="large fa fa-wikipedia-w" aria-hidden="true"></i>
		</a>
		</div>

		<div class="col s2">
		<a href="{{ url_for('translate') }}" class="btn-floating btn-large {{ buttonColor }}">
		    <i class="large material-icons">g_translate</i>
		</a>
		</div>

		<div class="col s2">
		<a href="{{ url_for('transport') }}" class="btn-floating btn-large {{ buttonColor }}">
			<i class="large fa fa-train" aria-hidden="true"></i>
		</a>
		</div>

	</div>

{% endblock %}
